﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'colorbutton', 'hu', {
	auto: 'Automatikus',
	bgColorTitle: 'Háttérszín',
	colors: {
		'000': 'Fekete',
		'800000': 'Bordó',
		'8B4513': 'Barna',
		'2F4F4F': 'Sötét türkiz',
		'008080': 'Türkiz',
		'000080': 'Király kék',
		'4B0082': 'Indigó kék',
		'696969': 'Szürke',
		B22222: 'Tégla vörös',
		A52A2A: 'Vörös',
		DAA520: 'Arany sárga',
		'006400': 'Sötét zöld',
		'40E0D0': 'Türkiz',
		'0000CD': 'Kék',
		'800080': 'Lila',
		'808080': 'Szürke',
		F00: 'Piros',
		FF8C00: 'Sötét narancs',
		FFD700: 'Arany',
		'008000': 'Zöld',
		'0FF': 'Türkiz',
		'00F': 'Kék',
		EE82EE: 'Rózsaszín',
		A9A9A9: 'Sötét szürke',
		FFA07A: 'Lazac',
		FFA500: 'Narancs',
		FFFF00: 'Citromsárga',
		'00FF00': 'Neon zöld',
		AFEEEE: 'Világos türkiz',
		ADD8E6: 'Világos kék',
		DDA0DD: 'Világos lila',
		D3D3D3: 'Világos szürke',
		FFF0F5: 'Lavender Blush',
		FAEBD7: 'Törtfehér',
		FFFFE0: 'Világos sárga',
		F0FFF0: 'Menta',
		F0FFFF: 'Azúr kék',
		F0F8FF: 'Halvány kék',
		E6E6FA: 'Lavender',
		FFF: 'Fehér',
		'1ABC9C': 'Erős cián',
		'2ECC71': 'Smaragd',
		'3498DB': 'Fényes kék',
		'9B59B6': 'Ametiszt',
		'4E5F70': 'Szürkéskék',
		'F1C40F': 'Világossárga',
		'16A085': 'Sötét cián',
		'27AE60': 'Sötét smaragd',
		'2980B9': 'Erős kék',
		'8E44AD': 'Sötétlila',
		'2C3E50': 'Világoskék',
		'F39C12': 'Narancs',
		'E67E22': 'Répa',
		'E74C3C': 'Sápadt vörös',
		'ECF0F1': 'Fényes ezüst',
		'95A5A6': 'Világos szürkés cián',
		'DDD': 'Világosszürke',
		'D35400': 'Tök',
		'C0392B': 'Erős vörös',
		'BDC3C7': 'Ezüst',
		'7F8C8D': 'Szürkés cián',
		'999': 'Sötétszürke'
	},
	more: 'További színek...',
	panelTitle: 'Színek',
	textColorTitle: 'Betűszín'
} );
